@@ -32,7 +32,8 @@ if (sourcedir != "") {
       })
     })
     
-    h5file <- "20170707-1355eco-test.h5"
+    #if you change the tar file then you must also change this file
+    h5file <- "20180423-1734eco-test.h5"
     
     deprintize<-function(f){
       return(function(...) {capture.output(w<-f(...));return(w);});
@@ -93,4 +94,7 @@ if (sourcedir != "") {
   }
   
   assign("nweeks", 2, envir = globalenv())
+  assign("nmonths", 2, envir = globalenv())
+  assign("firstDay", 113, envir = globalenv())
+  assign("lastDay", 126, envir = globalenv())
 }
