@@ -18,8 +18,8 @@ trueOpts <- list(
   scenarios = TRUE,
   mcYears = c(1,2),
   antaresVersion = 600L,
-  timeIdMin = 7 * 24 + 1,
-  timeIdMax = 24 * 7 * 3,
+  timeIdMin = (firstDay-1) * 24 + 1,
+  timeIdMax = lastDay*24,
   start = as.POSIXlt("2018-01-01", tz = "UTC"),
   firstWeekday = "Monday",
   areaList = c("a", "a_offshore", "b", "c", "hub", "psp in", "psp in-2", "psp out", 
